@@ -20,12 +20,11 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08320_01';
-
-require 5.006;
+our $VERSION = '0.08320_03';
 
 use strict;
 use warnings;
+use 5.006;
 use Config;
 use File::Spec;
 use File::Glob 'bsd_glob';
@@ -392,12 +391,12 @@ struct(
 
 sub _get_pc_varname {
     my ($self,$vname_base) = @_;
-    return $self->varclass . "::" . $vname_base;
+    $self->varclass . "::" . $vname_base;
 }
 
 sub _get_pc_udefname {
     my ($self,$vname_base) = @_;
-    return $self->udefclass . "::" . $vname_base;
+    $self->udefclass . "::" . $vname_base;
 }
 
 sub _pc_var {
@@ -406,9 +405,7 @@ sub _pc_var {
     no strict 'refs';
     $vname = $self->_get_pc_varname($vname);
     my $glob = *{$vname};
-    return unless $glob;
-    
-    return $$glob;
+    $glob ? $$glob : ();
 }
 
 sub _quote_cvt($)  {
@@ -532,7 +529,7 @@ sub find {
         }
     }
     
-    return $o;
+    $o;
 }
 
 ################################################################################
@@ -613,7 +610,7 @@ sub get_requires {
         }
     }
     #log_debug(@ret);
-    return @ret;
+    @ret;
 }
 
 
@@ -786,13 +783,17 @@ sub find_pcfile {
 ################################################################################
 ################################################################################
 
+sub _return_context (@) {
+    wantarray ? (@_) : join(' ', map { s/(\s|['"])/\\$1/g; $_ } @_)
+}
+
 sub get_cflags {
     my $self = shift;
     my @cflags = @{$self->cflags};
 
     filter_omit(\@cflags, $self->exclude_cflags);
     filter_dups(\@cflags);
-    return @cflags;
+    _return_context @cflags;
 }
 
 sub get_ldflags {
@@ -812,7 +813,7 @@ sub get_ldflags {
     @ret = reverse @ret;
     filter_dups(\@ret);
     @ret = reverse(@ret);
-    return @ret;
+    _return_context @ret;
 }
 
 sub get_var {
@@ -834,7 +835,7 @@ sub get_list {
             }
         }
     }
-    return @rv;
+    @rv;
 }
 
 
@@ -853,10 +854,11 @@ sub _split_flags {
     if(@flags == 1) {
         my $str = shift @flags;
         return () if !$str;
-        @flags = map { s/\\(\s)/$1/g; $_ } split(/(?<!\\)\s+/, $str);
+        #@flags = map { s/\\(\s)/$1/g; $_ } split(/(?<!\\)\s+/, $str);
+        @flags = shellwords $str;
     }
     @flags = grep $_, @flags;
-    return @flags;
+    @flags;
 }
 
 
@@ -901,7 +903,7 @@ sub version_2_array {
         && $chunk =~ /^\d+$/) {
         push @ret, $chunk;
     }
-    return @ret;
+    @ret;
 }
 
 
@@ -919,7 +921,7 @@ sub version_check {
             return 0;
         }
     }
-    return 1;
+    1;
 }
 
 
@@ -1158,7 +1160,7 @@ if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
     @print_flags = grep /^-[LR]/, $o->get_ldflags;
 }
 
-print $_, " " for @print_flags;
+print scalar PkgConfig::_return_context(@print_flags);
 print "\n";
 exit(0);
 
@@ -1412,7 +1414,15 @@ The version of the package
 
 =head4 I<< $o->get_ldflags >>
 
-Returns a list of compiler and linker flags, respectively.
+Returns compiler and linker flags, respectively.
+
+In list context, these methods return a list with each argument split on
+unescaped spaces.
+
+In list context returns a list of compiler and linker flags, respectively.
+
+In scalar context returns a string of compiler and linker flags with spaces
+and quotes escaped correctly.
 
 =head4 I<< $o->get_var($name) >>
 
